# Microservice CLI

Tool for manage the talk-point microservices.

## Install

````sh
$ pip install shopcloud-microservice
````

## Security

```sh
$ microservice security merge-security-pull-requests
```
